@@ -4,8 +4,11 @@ module Braintree
       include BaseModule
 
       attr_reader :bin
+      attr_reader :business
       attr_reader :card_type
       attr_reader :commercial
+      attr_reader :consumer
+      attr_reader :corporate
       attr_reader :country_of_issuance
       attr_reader :debit
       attr_reader :durbin_regulated
@@ -17,10 +20,12 @@ module Braintree
       attr_reader :image_url
       attr_reader :issuing_bank
       attr_reader :last_4
+      attr_reader :payment_account_reference
       attr_reader :payroll
       attr_reader :prepaid
       attr_reader :prepaid_reloadable
       attr_reader :product_id
+      attr_reader :purchase
       attr_reader :source_card_last_4
       attr_reader :source_card_type
       attr_reader :source_description
